==> qmmp-0.8.0.tar.bz2: qmmp-0.8.0/src/plugins/General/copypaste/translations/copypaste_plugin_sr_BA.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="sr_BA">
<context>
    <name>CopyPaste</name>
    <message>
        <location filename="../copypaste.cpp" line="43"/>
        <source>Cu&amp;t</source>
        <translation>&amp;Исијеци</translation>
    </message>
    <message>
        <location filename="../copypaste.cpp" line="44"/>
        <source>Ctrl+X</source>
        <translation>Ctrl+X</translation>
    </message>
    <message>
        <location filename="../copypaste.cpp" line="45"/>
        <source>&amp;Copy</source>
        <translation>&amp;Копирај</translation>
    </message>
    <message>
        <location filename="../copypaste.cpp" line="46"/>
        <source>Ctrl+C</source>
        <translation>Ctrl+C</translation>
    </message>
    <message>
        <location filename="../copypaste.cpp" line="47"/>
        <source>&amp;Paste</source>
        <translation>&amp;Налијепи</translation>
    </message>
    <message>
        <location filename="../copypaste.cpp" line="48"/>
        <source>Ctrl+V</source>
        <translation>Ctrl+V</translation>
    </message>
</context>
<context>
    <name>CopyPasteFactory</name>
    <message>
        <location filename="../copypastefactory.cpp" line="28"/>
        <source>Copy/Paste Plugin</source>
        <translation>Копирај/налијепи</translation>
    </message>
    <message>
        <location filename="../copypastefactory.cpp" line="48"/>
        <source>About Copy/Paste Plugin</source>
        <translation>О прикључку за копирање/лијепљење</translation>
    </message>
    <message>
        <location filename="../copypastefactory.cpp" line="49"/>
        <source>Qmmp Copy/Paste Plugin</source>
        <translation>Кумп прикључак за копирање/лијепљење</translation>
    </message>
    <message>
        <location filename="../copypastefactory.cpp" line="50"/>
        <source>This plugin allows to copy selected tracks from one playlist to another</source>
        <translation>Омогућује копирање изабране нумере са једне листе нумера на другу</translation>
    </message>
    <message>
        <location filename="../copypastefactory.cpp" line="51"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>Аутор: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
</context>
</TS>

==> qmmp_0.8.2.orig.tar.bz2: qmmp-0.8.2/src/plugins/General/copypaste/translations/copypaste_plugin_sr_BA.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="sr_BA">
<context>
    <name>CopyPaste</name>
    <message>
        <location filename="../copypaste.cpp" line="43"/>
        <source>Cu&amp;t</source>
        <translation>&amp;Исијеци</translation>
    </message>
    <message>
        <location filename="../copypaste.cpp" line="44"/>
        <source>Ctrl+X</source>
        <translation>Ctrl+X</translation>
    </message>
    <message>
        <location filename="../copypaste.cpp" line="45"/>
        <source>&amp;Copy</source>
        <translation>&amp;Копирај</translation>
    </message>
    <message>
        <location filename="../copypaste.cpp" line="46"/>
        <source>Ctrl+C</source>
        <translation>Ctrl+C</translation>
    </message>
    <message>
        <location filename="../copypaste.cpp" line="47"/>
        <source>&amp;Paste</source>
        <translation>&amp;Налијепи</translation>
    </message>
    <message>
        <location filename="../copypaste.cpp" line="48"/>
        <source>Ctrl+V</source>
        <translation>Ctrl+V</translation>
    </message>
</context>
<context>
    <name>CopyPasteFactory</name>
    <message>
        <location filename="../copypastefactory.cpp" line="28"/>
        <source>Copy/Paste Plugin</source>
        <translation>Копирај/налијепи</translation>
    </message>
    <message>
        <location filename="../copypastefactory.cpp" line="48"/>
        <source>About Copy/Paste Plugin</source>
        <translation>О прикључку за копирање/лијепљење</translation>
    </message>
    <message>
        <location filename="../copypastefactory.cpp" line="49"/>
        <source>Qmmp Copy/Paste Plugin</source>
        <translation>Кумп прикључак за копирање/лијепљење</translation>
    </message>
    <message>
        <location filename="../copypastefactory.cpp" line="50"/>
        <source>This plugin allows one to copy selected tracks from one playlist to another</source>
        <translation>Омогућује копирање изабране нумере са једне листе нумера на другу</translation>
    </message>
    <message>
        <location filename="../copypastefactory.cpp" line="51"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>Аутор: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
</context>
</TS>
